@@ -1,18 +1,25 @@
 import copy
+import json
 
 from jsonizer import Jsonizer
 from tonclient.types import AbiContract, AbiFunction, AbiEvent, AbiData, AbiParam
 
 
-def json_to_abi(json: dict, mutate: bool = False) -> AbiContract:
+def file_to_abi(filename: str) -> AbiContract:
+    with open(filename, 'r') as file:
+        data = json.load(file)
+    return json_to_abi(data, mutate=True)
+
+
+def json_to_abi(data: dict, mutate: bool = False) -> AbiContract:
     # fix abi events - removing "outputs" field
-    if len(json['events']) > 0:
+    if len(data['events']) > 0:
         if not mutate:
-            json = copy.deepcopy(json)
-        for event in json['events']:
+            data = copy.deepcopy(data)
+        for event in data['events']:
             event.pop('outputs', None)
     parser = Jsonizer(AbiContract, AbiFunction, AbiEvent, AbiData, AbiParam, lowercase_keys=True, replace_space='_')
-    return parser.parse(json)
+    return parser.parse(data)
 
 
 def abi_params_to_str(abi_params: list[AbiParam]) -> str:
